API Reference
=============

Corner-point Grid
-----------------

.. automodule:: resfo_utilities._cornerpoint_grid

.. autoclass:: resfo_utilities.CornerpointGrid
   :members:

.. autoclass:: resfo_utilities.InvalidEgridFileError

.. autoclass:: resfo_utilities.MapAxes
   :members:

Summaries
---------

.. automodule:: resfo_utilities._summary_reader

.. autoclass:: resfo_utilities.SummaryReader
   :members:

.. autoclass:: resfo_utilities.InvalidSummaryError

.. autoclass:: resfo_utilities.SummaryKeyword
   :members:

Summarykeys
------------

.. automodule:: resfo_utilities._summary_keys

.. autofunction:: resfo_utilities.make_summary_key

.. autofunction:: resfo_utilities.InvalidSummaryKeyError

.. autoclass:: resfo_utilities.SummaryKeyType
   :members:

.. autofunction:: resfo_utilities.is_rate

.. autofunction:: resfo_utilities.history_key


Testing
-------

.. automodule:: resfo_utilities.testing
   :members:
